@@ -35,7 +35,7 @@ def time_determination(time):
 
 
 class ROSSPkg():
-    def __init__(self, verbose = False):       
+    def __init__(self, verbose = False, jupyter = False):       
         # establish the general organization structures
         self.parameters = {}
         self.variables = {}
@@ -589,7 +589,6 @@ class ROSSPkg():
             self.parameters['output_path'] = os.path.join(self.simulation_path, self.parameters['output_file_name'])
         else:
             self.parameters['output_path'] = output_path    
-            
         
         # define a table of parameters
         parameters = {'parameter':[], 'value':[]}
@@ -600,7 +599,10 @@ class ROSSPkg():
             parameters['value'].append(self.parameters[parameter])
         parameters_table = pandas.DataFrame(parameters)
         if self.verbose:
-            print(parameters_table)
+            if jupyter:
+                display(parameters_table)
+            else:
+                print(parameters_table)
         
         parameters_path = os.path.join(self.simulation_path, 'parameters.csv')
         parameters_table.to_csv(parameters_path)
@@ -614,7 +616,10 @@ class ROSSPkg():
             variables['value'].append(self.variables[variable])
         variables_table = pandas.DataFrame(variables)
         if self.verbose:
-            print(variables_table)
+            if jupyter:
+                display(variables_table)
+            else:
+                print(variables_table)
         
         variables_path = os.path.join(self.simulation_path, 'variables.csv')
         variables_table.to_csv(variables_path)
@@ -657,7 +662,10 @@ class ROSSPkg():
             self.results['csv_data'] = pandas.DataFrame(conc, columns = headers)
             if self.verbose:
                 pandas.set_option('display.max_columns', None)
-                print(self.results['csv_data'])
+                if jupyter:
+                    display(self.results['csv_data'])
+                else:
+                    print(self.results['csv_data'])
             fobj.write(self.results['csv_data'].to_string())
             
             self.variables['run_time (s)'] = float(run_time)
@@ -832,7 +840,10 @@ class ROSSPkg():
         concentrations_table.index.name = x_label
         concentrations_table.to_csv(os.path.join(self.simulation_path, 'brine_concentrations.csv'))
         if self.verbose:
-            print(concentrations_table)
+            if jupyter:
+                display(concentrations_table)
+            else:
+                print(concentrations_table)
         return concentrations_table            
 
     def scaling_plot(self, plot_title, title_font, label_font, plot_caption, individual_plots, legend_title = None, x_label_number = 6, export_name = None, export_format = 'svg'):
